pub struct AccountInfoStorageMapKeyProvider;Expand description
Provides a storage key for account data.
We need to use this approach when we don’t have access to the runtime.
The equivalent command to invoke in case full Runtime is known is this:
let key = frame_system::Account::<Runtime>::storage_map_final_key(&account_id);
Implementations